@@ -321,13 +321,9 @@ class Region:
           unreasonable amount of time (AKA Gecko).
         """
 
-        # Double check for ellipses.
-        #
-        maskSize = len(self.string) + (2 * self.string.count('\u2026'))
-
         # Create an empty mask.
         #
-        return '\x00' * maskSize
+        return '\x00' * len(self.string)
 
     def repositionCursor(self):
         """Reposition the cursor offset for contracted mode.
@@ -854,11 +850,7 @@ class Line:
             if region == _regionWithFocus:
                 focusOffset = len(string)
             if region.string:
-                # [[[TODO: WDW - HACK: Replace ellipses with "..."
-                # The ultimate solution is to get i18n support into
-                # BrlTTY.]]]
-                #
-                string += region.string.replace('\u2026', "...")
+                string += region.string
             mask = region.getAttributeMask(getLinkMask)
             attributeMask += mask
 
@@ -1149,6 +1141,7 @@ def _realignViewport(string, focusOffset, cursorOffset):
         #
         viewport[0] = min(viewport[0],
                           max(leftMostEdge, len(string) - _displaySize[0]))
+        viewport[0] = int(viewport[0])
 
 def refresh(panToCursor=True,
             targetCursorCell=0,
@@ -1279,7 +1272,7 @@ def refresh(panToCursor=True,
     #
     _realignViewport(string, focusOffset, cursorOffset)
 
-    startPos = viewport[0]
+    startPos = int(viewport[0])
     endPos = startPos + _displaySize[0]
 
     # Now normalize the cursor position to BrlTTY, which uses 1 as
