@@ -197,7 +197,7 @@ formatting = {
         },
         pyatspi.ROLE_FORM: {
             'focused': 'leaving or (labelAndName + roleName)',
-            'unfocused': '((substring and currentLineText) or labelAndName) + roleName + pause + unrelatedLabels'
+            'unfocused': '((substring and currentLineText) or labelAndName) + roleName'
             },
         pyatspi.ROLE_FRAME: {
             'focused': 'labelOrName + roleName',
@@ -225,9 +225,9 @@ formatting = {
             'unfocused': 'labelAndName + unrelatedLabels'
             },
         pyatspi.ROLE_LABEL: {
-            'focused': 'displayedText + allTextSelection + roleName',
-            'unfocused': 'displayedText + allTextSelection + roleName',
-            'basicWhereAmI': 'displayedText + allTextSelection + roleName'
+            'focused': 'label + displayedText + allTextSelection + roleName',
+            'unfocused': 'label + displayedText + allTextSelection + roleName',
+            'basicWhereAmI': 'label + displayedText + allTextSelection + roleName'
             },
         pyatspi.ROLE_LANDMARK: {
             'focused': 'leaving or (labelAndName + roleName)',
