@@ -37,7 +37,6 @@ import orca.orca_state as orca_state
 import orca.speech as speech
 import orca.scripts.toolkits.Gecko as Gecko
 
-from .speech_generator import SpeechGenerator
 from .spellcheck import SpellCheck
 
 _settingsManager = settings_manager.getManager()
@@ -78,10 +77,15 @@ class Script(Gecko.Script):
                 Script.togglePresentationMode,
                 cmdnames.TOGGLE_PRESENTATION_MODE)
 
-    def getSpeechGenerator(self):
-        """Returns the speech generator for this script."""
+        self.inputEventHandlers["enableStickyFocusModeHandler"] = \
+            input_event.InputEventHandler(
+                Script.enableStickyFocusMode,
+                cmdnames.SET_FOCUS_MODE_STICKY)
 
-        return SpeechGenerator(self)
+        self.inputEventHandlers["enableStickyBrowseModeHandler"] = \
+            input_event.InputEventHandler(
+                Script.enableStickyBrowseMode,
+                cmdnames.SET_BROWSE_MODE_STICKY)
 
     def getSpellCheck(self):
         """Returns the spellcheck support for this script."""
@@ -135,7 +139,7 @@ class Script(Gecko.Script):
         super().locusOfFocusChanged(event, oldFocus, newFocus)
 
     def useFocusMode(self, obj):
-        if self.isEditableMessage(obj):
+        if self.utilities.isEditableMessage(obj):
             msg = "THUNDERBIRD: Using focus mode for editable message %s" % obj
             debug.println(debug.LEVEL_INFO, msg, True)
             return True
@@ -144,8 +148,20 @@ class Script(Gecko.Script):
         debug.println(debug.LEVEL_INFO, msg, True)
         return super().useFocusMode(obj)
 
+    def enableStickyBrowseMode(self, inputEvent, forceMessage=False):
+        if self.utilities.isEditableMessage(orca_state.locusOfFocus):
+            return
+
+        super().enableStickyBrowseMode(inputEvent, forceMessage)
+
+    def enableStickyFocusMode(self, inputEvent, forceMessage=False):
+        if self.utilities.isEditableMessage(orca_state.locusOfFocus):
+            return
+
+        super().enableStickyFocusMode(inputEvent, forceMessage)
+
     def togglePresentationMode(self, inputEvent):
-        if self._inFocusMode and self.isEditableMessage(orca_state.locusOfFocus):
+        if self._inFocusMode and self.utilities.isEditableMessage(orca_state.locusOfFocus):
             return
 
         super().togglePresentationMode(inputEvent)
@@ -153,7 +169,7 @@ class Script(Gecko.Script):
     def useStructuralNavigationModel(self):
         """Returns True if structural navigation should be enabled here."""
 
-        if self.isEditableMessage(orca_state.locusOfFocus):
+        if self.utilities.isEditableMessage(orca_state.locusOfFocus):
             return False
 
         return super().useStructuralNavigationModel()
@@ -176,7 +192,7 @@ class Script(Gecko.Script):
             super().onFocusedChanged(event)
             return
 
-        if self.isEditableMessage(obj):
+        if self.utilities.isEditableMessage(obj):
             super().onFocusedChanged(event)
             return
 
@@ -186,7 +202,7 @@ class Script(Gecko.Script):
         """Callback for object:state-changed:busy accessibility events."""
 
         obj = event.source
-        if obj.getRole() == pyatspi.ROLE_DOCUMENT_FRAME and not event.detail1:
+        if self.utilities.isDocument(obj) and not event.detail1:
             try:
                 role = orca_state.locusOfFocus.getRole()
                 name = orca_state.locusOfFocus.name
@@ -203,7 +219,7 @@ class Script(Gecko.Script):
     def onCaretMoved(self, event):
         """Callback for object:text-caret-moved accessibility events."""
 
-        if self.isEditableMessage(event.source):
+        if self.utilities.isEditableMessage(event.source):
             if event.detail1 == -1:
                 return
             self.spellcheck.setDocumentPosition(event.source, event.detail1)
@@ -286,7 +302,7 @@ class Script(Gecko.Script):
 
         # Try to stop unwanted chatter when a message is being replied to.
         # See bgo#618484.
-        if isSystemEvent and self.isEditableMessage(obj):
+        if isSystemEvent and self.utilities.isEditableMessage(obj):
             return
 
         # Speak the autocompleted text, but only if it is different
@@ -323,7 +339,7 @@ class Script(Gecko.Script):
         if obj == spellCheckEntry:
             return
 
-        if self.isEditableMessage(obj) and self.spellcheck.isActive():
+        if self.utilities.isEditableMessage(obj) and self.spellcheck.isActive():
             text = obj.queryText()
             selStart, selEnd = text.getSelection(0)
             self.spellcheck.setDocumentPosition(obj, selStart)
@@ -338,25 +354,13 @@ class Script(Gecko.Script):
             self.spellcheck.presentErrorDetails()
             return
 
-        obj = event.source
+        if not self.utilities.lastInputEventWasDelete() \
+           or not self.utilities.isDocument(event.source):
+            return
 
-        # If the user has just deleted an open mail message, then we want to
-        # try to speak the new name of the open mail message frame and also
-        # present the first line of that message to be consistent with what
-        # we do when a new message window is opened. See bug #540039 for more
-        # details.
-        #
-        rolesList = [pyatspi.ROLE_DOCUMENT_FRAME,
-                     pyatspi.ROLE_INTERNAL_FRAME,
-                     pyatspi.ROLE_FRAME,
-                     pyatspi.ROLE_APPLICATION]
-        if self.utilities.hasMatchingHierarchy(event.source, rolesList):
-            lastKey, mods = self.utilities.lastKeyAndModifiers()
-            if lastKey == "Delete":
-                speech.speak(obj.name)
-                [obj, offset] = self.utilities.findFirstCaretContext(obj, 0)
-                self.utilities.setCaretPosition(obj, offset)
-                return
+        speech.speak(obj.name)
+        [obj, offset] = self.utilities.findFirstCaretContext(obj, 0)
+        self.utilities.setCaretPosition(obj, offset)
 
     def _presentMessage(self, documentFrame):
         """Presents the first line of the message, or the entire message,
@@ -388,7 +392,7 @@ class Script(Gecko.Script):
     def sayCharacter(self, obj):
         """Speaks the character at the current caret position."""
 
-        if self.isEditableMessage(obj):
+        if self.utilities.isEditableMessage(obj):
             text = self.utilities.queryNonEmptyText(obj)
             if text and text.caretOffset + 1 >= text.characterCount:
                 default.Script.sayCharacter(self, obj)
@@ -419,31 +423,6 @@ class Script(Gecko.Script):
 
         return default.Script.toggleFlatReviewMode(self, inputEvent)
 
-    def isNonHTMLEntry(self, obj):
-        """Checks for ROLE_ENTRY areas that are not part of an HTML
-        document.  See bug #607414.
-
-        Returns True is this is something like the Subject: entry
-        """
-        result = obj and obj.getRole() == pyatspi.ROLE_ENTRY \
-            and not self.utilities.ancestorWithRole(
-                obj, [pyatspi.ROLE_DOCUMENT_FRAME], [pyatspi.ROLE_FRAME])
-        return result
-
-    def isEditableMessage(self, obj):
-        """Returns True if this is a editable message."""
-
-        if not obj:
-            return False
-
-        if not obj.getState().contains(pyatspi.STATE_EDITABLE):
-            return False
-
-        if self.isNonHTMLEntry(obj):
-            return False
-
-        return True
-
     def onWindowActivated(self, event):
         """Callback for window:activate accessibility events."""
 
