@@ -57,20 +57,29 @@ class Script(gtk.Script):
 
         return grid
 
-    def setAppPreferences(self, prefs):
-        """Write out the application specific preferences lines and set the
-        new values."""
+    def getPreferencesFromGUI(self):
+        """Returns a dictionary with the app-specific preferences."""
 
-        self.spellcheck.setAppPreferences(prefs)
+        return self.spellcheck.getPreferencesFromGUI()
 
     def doWhereAmI(self, inputEvent, basicOnly):
         """Performs the whereAmI operation."""
 
         if self.spellcheck.isActive():
             self.spellcheck.presentErrorDetails(not basicOnly)
+
+        super().doWhereAmI(inputEvent, basicOnly)
+
+    def locusOfFocusChanged(self, event, oldFocus, newFocus):
+        """Handles changes of focus of interest to the script."""
+
+        if self.spellcheck.isSuggestionsItem(newFocus):
+            includeLabel = not self.spellcheck.isSuggestionsItem(oldFocus)
+            self.updateBraille(newFocus)
+            self.spellcheck.presentSuggestionListItem(includeLabel=includeLabel)
             return
 
-        gtk.Script.doWhereAmI(self,inputEvent, basicOnly)
+        super().locusOfFocusChanged(event, oldFocus, newFocus)
 
     def onActiveDescendantChanged(self, event):
         """Callback for object:active-descendant-changed accessibility events."""
@@ -95,13 +104,6 @@ class Script(gtk.Script):
         if not event.detail1:
             return
 
-        if self.spellcheck.isSuggestionsItem(event.source) \
-           and self.spellcheck.isSuggestionsItem(orca_state.locusOfFocus):
-            orca.setLocusOfFocus(event, event.source, False)
-            self.updateBraille(orca_state.locusOfFocus)
-            self.spellcheck.presentSuggestionListItem()
-            return
-
         gtk.Script.onFocusedChanged(self, event)
 
     def onNameChanged(self, event):
@@ -149,6 +151,9 @@ class Script(gtk.Script):
         if not self.utilities.isSearchEntry(orca_state.locusOfFocus, True):
             return
 
+        if not self.utilities.isShowingAndVisible(event.source):
+            return
+
         # To avoid extreme chattiness.
         keyString, mods = self.utilities.lastKeyAndModifiers()
         if keyString in ["BackSpace", "Delete"]:
