@@ -111,29 +111,44 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         object will be used.  This method will return an empty array
         if nothing can be found.
         """
-        role = args.get('role', obj.getRole())
-        if role == pyatspi.ROLE_TEXT and obj.parent.getRole() == pyatspi.ROLE_COMBO_BOX:
-            return []
 
-        if role in [pyatspi.ROLE_PUSH_BUTTON, pyatspi.ROLE_TOGGLE_BUTTON] \
-           and self._script.utilities.ancestorWithRole(
-                obj, [pyatspi.ROLE_TOOL_BAR], [pyatspi.ROLE_FRAME]):
-            acss = self.voice(speech_generator.SYSTEM)
+        # TODO - JD: This should be the behavior by default. But the default
+        # generators call displayedText(). Once that is corrected, this method
+        # can be removed.
+        if obj.name:
             result = [obj.name]
-            if result:
-                result.extend(acss)
-                return result
+            result.extend(self.voice(speech_generator.DEFAULT))
+            return result
 
-        return speech_generator.SpeechGenerator._generateName(
-            self, obj, **args)
+        return super()._generateName(obj, **args)
+
+    def _generateLabelAndName(self, obj, **args):
+        if obj.getRole() != pyatspi.ROLE_COMBO_BOX:
+            return super()._generateLabelAndName(obj, **args)
+
+        # TODO - JD: This should be the behavior by default because many
+        # toolkits use the label for the name.
+        result = []
+        label = self._script.utilities.displayedLabel(obj)
+        if label:
+            result.append(label)
+            result.extend(self.voice(speech_generator.DEFAULT))           
+
+        name = obj.name
+        if label == name or not name:
+            selected = self._script.utilities.selectedChildren(obj)
+            if selected:
+                name = selected[0].name
+
+        if name:
+            result.append(name)
+            result.extend(self.voice(speech_generator.DEFAULT))
+
+        return result
 
     def _generateLabelOrName(self, obj, **args):
         """Gets the label or the name if the label is not preset."""
 
-        role = args.get('role', obj.getRole())
-        if role == pyatspi.ROLE_TEXT and obj.parent.getRole() == pyatspi.ROLE_COMBO_BOX:
-            return []
-
         result = []
         acss = self.voice(speech_generator.DEFAULT)
         override = self.__overrideParagraph(obj, **args)
@@ -162,6 +177,13 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
                 self, obj, **args))
         return result
 
+    def _generateAnyTextSelection(self, obj, **args):
+        comboBoxEntry = self._script.utilities.getEntryForEditableComboBox(obj)
+        if comboBoxEntry:
+            return super()._generateAnyTextSelection(comboBoxEntry)
+
+        return super()._generateAnyTextSelection(obj, **args)
+
     def _generateAvailability(self, obj, **args):
         """Returns an array of strings for use by speech and braille that
         represent the grayed/sensitivity/availability state of the
@@ -185,6 +207,9 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         if _settingsManager.getSetting('onlySpeakDisplayedText'):
             return []
 
+        if not _settingsManager.getSetting('speakDescription'):
+            return []
+
         if not args.get('formatType', '').endswith('WhereAmI'):
             return []
 
@@ -214,6 +239,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             if priorObj and priorObj.parent != obj.parent:
                 return []
 
+        if obj.getRole() == pyatspi.ROLE_COMBO_BOX:
+            entry = self._script.utilities.getEntryForEditableComboBox(obj)
+            if entry:
+                return super()._generateCurrentLineText(entry)
+            return []
+
         # TODO - JD: The SayLine, etc. code should be generated and not put
         # together in the scripts. In addition, the voice crap needs to go
         # here. Then it needs to be removed from the scripts.
@@ -343,7 +374,7 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             return []
 
         text = self._script.utilities.displayedText(inputLine)
-        if text.startswith("="):
+        if text and text.startswith("="):
             result = [messages.HAS_FORMULA]
             result.extend(self.voice(speech_generator.SYSTEM))
             return result
@@ -361,10 +392,15 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         Returns a list of utterances to be spoken for the object.
         """
 
-        result = speech_generator.SpeechGenerator._generateRealTableCell(
-            self, obj, **args)
+        if self._script.inSayAll():
+            return []
+
+        result = super()._generateRealTableCell(obj, **args)
 
         if not self._script.utilities.isSpreadSheetCell(obj):
+            if self._script._lastCommandWasStructNav:
+                return result
+
             if _settingsManager.getSetting('speakCellCoordinates'):
                 result.append(obj.name)
             return result
@@ -393,24 +429,17 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         return result
 
     def _generateTableCellRow(self, obj, **args):
-        """Get the speech for a table cell row if the user wants to hear
-        the full row and if the row has actually changed."""
-
-        speakFullRow = self._script.utilities.shouldReadFullRow(obj)
-        if speakFullRow:
-            row, column, table = \
-                self._script.utilities.getRowColumnAndTable(obj)
-            lastRow = self._script.pointOfReference.get("lastRow")
-            if lastRow == -1 and self._script.utilities.isSpreadSheetCell(obj):
-                speakFullRow = False
-            else:
-                speakFullRow = row != lastRow
-
-        if not speakFullRow:
+        if not self._script.utilities.shouldReadFullRow(obj):
             return self._generateRealTableCell(obj, **args)
 
+        if not self._script.utilities.isSpreadSheetCell(obj):
+            return super()._generateTableCellRow(obj, **args)
+
+        cells = self._script.utilities.getShowingCellsInSameRow(obj)
+        if not cells:
+            return []
+
         result = []
-        cells = self._script.utilities.getShowingCellsInRow(obj)
         for cell in cells:
             result.extend(self._generateRealTableCell(cell, **args))
 
@@ -424,50 +453,43 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
         dialog).
         """
 
+        if self._script._lastCommandWasStructNav or self._script.inSayAll():
+            return []
+
         topLevel = self._script.utilities.topLevelObject(obj)
         if topLevel and topLevel.getRole() == pyatspi.ROLE_DIALOG:
             return []
 
-        return (speech_generator.SpeechGenerator._generateEndOfTableIndicator(
-                self, obj, **args))
+        return super()._generateEndOfTableIndicator(obj, **args)
 
     def _generateNewAncestors(self, obj, **args):
         priorObj = args.get('priorObj', None)
         if not priorObj or priorObj.getRoleName() == 'text frame':
             return []
 
-        return speech_generator.SpeechGenerator._generateNewAncestors(
-            self, obj, **args)
+        return super()._generateNewAncestors(obj, **args)
 
     def _generateOldAncestors(self, obj, **args):
         """Returns an array of strings (and possibly voice and audio
         specifications) that represent the text of the ancestors for
         the object being left."""
 
-        priorObj = args.get('priorObj', None)
-        if not priorObj:
-            return []
-
         if obj.getRoleName() == 'text frame':
             return []
 
-        isTable = lambda x: x and x.getRole() == pyatspi.ROLE_TABLE
-        oldTable = pyatspi.findAncestor(priorObj, isTable)
-        if oldTable:
-            ancestor = self._script.utilities.commonAncestor(oldTable, obj)
-            if ancestor and ancestor.getRole() == pyatspi.ROLE_DOCUMENT_FRAME:
-                result = [messages.TABLE_LEAVING]
-                result.extend(self.voice(speech_generator.SYSTEM))
-                result.extend(self._generatePause(obj, **args))
-                return result
+        priorObj = args.get('priorObj', None)
+        if self._script.utilities.isSpreadSheetCell(priorObj):
+            return []
 
-        return speech_generator.SpeechGenerator._generateOldAncestors(
-            self, obj, **args)
+        return super()._generateOldAncestors(obj, **args)
 
     def _generateUnselectedCell(self, obj, **args):
         if self._script.utilities.isSpreadSheetCell(obj):
             return []
 
+        if self._script._lastCommandWasStructNav:
+            return []
+
         return super()._generateUnselectedCell(obj, **args)
 
     def generateSpeech(self, obj, **args):
@@ -484,11 +506,12 @@ class SpeechGenerator(speech_generator.SpeechGenerator):
             # we can use to guess the coordinates.
             #
             args['guessCoordinates'] = obj.getRole() == pyatspi.ROLE_PARAGRAPH
-            result.extend(speech_generator.SpeechGenerator.\
-                                           generateSpeech(self, obj, **args))
+            result.extend(super().generateSpeech(obj, **args))
             del args['guessCoordinates']
             self._restoreRole(oldRole, args)
         else:
-            result.extend(speech_generator.SpeechGenerator.\
-                                           generateSpeech(self, obj, **args))
+            oldRole = self._overrideRole(self._getAlternativeRole(obj, **args), args)
+            result.extend(super().generateSpeech(obj, **args))
+            self._restoreRole(oldRole, args)
+
         return result
