@@ -26,6 +26,7 @@ __copyright__ = "Copyright (c) 2013-2014 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
+import time
 
 import orca.debug as debug
 import orca.orca as orca
@@ -42,6 +43,18 @@ class Script(default.Script):
     def getUtilities(self):
         return Utilities(self)
 
+    def locusOfFocusChanged(self, event, oldFocus, newFocus):
+        """Handles changes of focus of interest to the script."""
+
+        if self.utilities.isInOpenMenuBarMenu(newFocus):
+            window = self.utilities.topLevelObject(newFocus)
+            windowChanged = window and orca_state.activeWindow != window
+            if windowChanged:
+                orca_state.activeWindow = window
+                self.windowActivateTime = time.time()
+
+        super().locusOfFocusChanged(event, oldFocus, newFocus)
+
     def onActiveDescendantChanged(self, event):
         """Callback for object:active-descendant-changed accessibility events."""
 
