@@ -56,6 +56,12 @@ class Script(web.Script):
 
         return Utilities(self)
 
+    def isActivatableEvent(self, event):
+        if event.type == "window:activate":
+            return self.utilities.canBeActiveWindow(event.source)
+
+        return super().isActivatableEvent(event)
+
     def locusOfFocusChanged(self, event, oldFocus, newFocus):
         """Handles changes of focus of interest to the script."""
 
@@ -72,6 +78,10 @@ class Script(web.Script):
         if super().onActiveChanged(event):
             return
 
+        if event.detail1 and event.source.getRole() == pyatspi.ROLE_FRAME \
+           and not self.utilities.canBeActiveWindow(event.source):
+            return
+
         msg = "GECKO: Passing along event to default script"
         debug.println(debug.LEVEL_INFO, msg, True)
         default.Script.onActiveChanged(self, event)
@@ -79,6 +89,20 @@ class Script(web.Script):
     def onBusyChanged(self, event):
         """Callback for object:state-changed:busy accessibility events."""
 
+        try:
+            name = event.source.name
+        except:
+            msg = "GECKO: Exception getting name of event source"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
+
+        # Sadly this document frame claims to be visible and showing and have all
+        # the other characteristics of a real page. Hence the name check.
+        if "self-repair.mozilla.org" in name:
+            msg = "GECKO: Ignoring event because it's not a real (to users) page"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
+
         if super().onBusyChanged(event):
             return
 
@@ -294,6 +318,9 @@ class Script(web.Script):
     def onWindowActivated(self, event):
         """Callback for window:activate accessibility events."""
 
+        if not self.utilities.canBeActiveWindow(event.source):
+            return
+
         if super().onWindowActivated(event):
             return
 
