@@ -26,6 +26,7 @@ __copyright__ = "Copyright (c) 2013-2014 Igalia, S.L."
 __license__   = "LGPL"
 
 import pyatspi
+import time
 
 import orca.debug as debug
 import orca.orca as orca
@@ -56,6 +57,12 @@ class Script(default.Script):
             isComboBox = lambda x: x and x.getRole() == pyatspi.ROLE_COMBO_BOX
             newFocus = pyatspi.findAncestor(newFocus, isComboBox) or newFocus
             orca.setLocusOfFocus(event, newFocus, False)
+        elif self.utilities.isInOpenMenuBarMenu(newFocus):
+            window = self.utilities.topLevelObject(newFocus)
+            windowChanged = window and orca_state.activeWindow != window
+            if windowChanged:
+                orca_state.activeWindow = window
+                self.windowActivateTime = time.time()
 
         super().locusOfFocusChanged(event, oldFocus, newFocus)
 
@@ -192,6 +199,16 @@ class Script(default.Script):
             orca.setLocusOfFocus(event, obj)
             return
 
+    def onFocusedChanged(self, event):
+        """Callback for object:state-changed:focused accessibility events."""
+
+        if self.utilities.isUselessPanel(event.source):
+            msg = "GTK: Event source believed to be useless panel"
+            debug.println(debug.LEVEL_INFO, msg, True)
+            return
+
+        super().onFocusedChanged(event)
+
     def onSelectedChanged(self, event):
         """Callback for object:state-changed:selected accessibility events."""
 
@@ -263,4 +280,7 @@ class Script(default.Script):
         if self.utilities.eventIsCanvasNoise(event):
             return False
 
+        if self.utilities.isUselessPanel(event.source):
+            return False
+
         return super().isActivatableEvent(event)
